@@ -134,7 +134,7 @@ class BaseLegacyActor(BaseActor):
             self.tron = None
 
         #: dict: Actor models.
-        self.models = self.tron.models if self.tron else None
+        self.models = self.tron.models if self.tron else {}
 
         self.timed_commands = TimedCommandList(self)
 
@@ -143,7 +143,7 @@ class BaseLegacyActor(BaseActor):
             f"<{str(self)} (name={self.name!r}, host={self.host!r}, port={self.port})>"
         )
 
-    async def start(self: T) -> T:
+    async def start(self: T, get_keys: bool = True) -> T:
         """Starts the server and the Tron client connection."""
 
         await self._server.start()
@@ -152,7 +152,7 @@ class BaseLegacyActor(BaseActor):
         # Start tron connection
         try:
             if self.tron:
-                await self.tron.start()
+                await self.tron.start(get_keys=get_keys)
                 self.log.info(
                     f"started tron connection at {self.tron.host}:{self.tron.port}"
                 )
@@ -358,7 +358,7 @@ class BaseLegacyActor(BaseActor):
                 target,
                 command_string,
                 *args,
-                commander=f"{self.name}.{self.name}",
+                commander=f"{self.name}.{target}",
                 mid=command_id,
                 callback=callback,
             )
